@@ -14,11 +14,13 @@ package org.eclipse.che.api.factory.server.bitbucket;
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.*;
 
 import org.eclipse.che.api.factory.server.scm.PersonalAccessToken;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
+import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
 import org.eclipse.che.api.factory.server.urlfactory.DevfileFilenamesProvider;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 import org.mockito.Mock;
@@ -80,4 +82,17 @@ public class BitbucketServerScmFileResolverTest {
 
     assertEquals(content, rawContent);
   }
+
+  @Test
+  public void shouldFetchContentWithoutAuthentication() throws Exception {
+    // given
+    when(personalAccessTokenManager.getAndStore(anyString()))
+        .thenThrow(new ScmUnauthorizedException("message", "bitbucket-server", "v1", "url"));
+
+    // when
+    serverScmFileResolver.fileContent("https://foo.bar/scm/~username/repo.git", "devfile.yaml");
+
+    // then
+    verify(urlFetcher).fetch(anyString());
+  }
 }
