@@ -16,6 +16,7 @@ import static org.eclipse.che.api.factory.shared.Constants.CURRENT_VERSION;
 import static org.eclipse.che.api.factory.shared.Constants.URL_PARAMETER_NAME;
 import static org.eclipse.che.api.workspace.server.devfile.Constants.CURRENT_API_VERSION;
 import static org.eclipse.che.dto.server.DtoFactory.newDto;
+import static org.eclipse.che.security.oauth1.OAuthAuthenticationService.ERROR_QUERY_NAME;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyMap;
@@ -33,6 +34,7 @@ import com.google.common.collect.ImmutableMap;
 import java.util.Collections;
 import java.util.Map;
 import java.util.Optional;
+import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.core.model.factory.ScmInfo;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.DevfileFilenamesProvider;
@@ -79,6 +81,7 @@ public class BitbucketFactoryParametersResolverTest {
   @Mock private URLFactoryBuilder urlFactoryBuilder;
 
   @Mock private PersonalAccessTokenManager personalAccessTokenManager;
+  @Mock private BitbucketApiClient bitbucketApiClient;
 
   /**
    * Capturing the location parameter when calling {@link
@@ -100,7 +103,8 @@ public class BitbucketFactoryParametersResolverTest {
             bitbucketSourceStorageBuilder,
             urlFactoryBuilder,
             projectConfigDtoMerger,
-            personalAccessTokenManager);
+            personalAccessTokenManager,
+            bitbucketApiClient);
     assertNotNull(this.bitbucketFactoryParametersResolver);
   }
 
@@ -273,4 +277,26 @@ public class BitbucketFactoryParametersResolverTest {
         .withSource("repo")
         .withDevfile(Map.of("schemaVersion", "2.0.0"));
   }
+
+  @Test
+  public void shouldCreateFactoryWithoutAuthentication() throws ApiException {
+    // given
+    String bitbucketUrl = "https://bitbucket.org/user/repo.git";
+    Map<String, String> params =
+        ImmutableMap.of(URL_PARAMETER_NAME, bitbucketUrl, ERROR_QUERY_NAME, "access_denied");
+    when(urlFactoryBuilder.createFactoryFromDevfile(
+            any(RemoteFactoryUrl.class), any(), anyMap(), anyBoolean()))
+        .thenReturn(Optional.of(generateDevfileFactory()));
+
+    // when
+    bitbucketFactoryParametersResolver.createFactory(params);
+
+    // then
+    verify(urlFactoryBuilder)
+        .createFactoryFromDevfile(
+            any(BitbucketUrl.class),
+            any(BitbucketAuthorizingFileContentProvider.class),
+            anyMap(),
+            eq(true));
+  }
 }
