@@ -12,6 +12,8 @@
 package org.eclipse.che.api.factory.server.bitbucket;
 
 import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.AssertJUnit.assertEquals;
 import static org.testng.AssertJUnit.assertFalse;
@@ -20,6 +22,7 @@ import static org.testng.AssertJUnit.assertTrue;
 
 import org.eclipse.che.api.factory.server.scm.PersonalAccessToken;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
+import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
 import org.eclipse.che.api.factory.server.urlfactory.DevfileFilenamesProvider;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 import org.mockito.Mock;
@@ -37,6 +40,7 @@ public class BitbucketScmFileResolverTest {
 
   @Mock private DevfileFilenamesProvider devfileFilenamesProvider;
   @Mock private PersonalAccessTokenManager personalAccessTokenManager;
+  @Mock private BitbucketApiClient bitbucketApiClient;
 
   private BitbucketScmFileResolver bitbucketScmFileResolver;
 
@@ -45,7 +49,8 @@ public class BitbucketScmFileResolverTest {
     bitbucketURLParser = new BitbucketURLParser(devfileFilenamesProvider);
     assertNotNull(this.bitbucketURLParser);
     bitbucketScmFileResolver =
-        new BitbucketScmFileResolver(bitbucketURLParser, urlFetcher, personalAccessTokenManager);
+        new BitbucketScmFileResolver(
+            bitbucketURLParser, urlFetcher, personalAccessTokenManager, bitbucketApiClient);
     assertNotNull(this.bitbucketScmFileResolver);
   }
 
@@ -67,7 +72,9 @@ public class BitbucketScmFileResolverTest {
   public void shouldReturnContentFromUrlFetcher() throws Exception {
     final String rawContent = "raw_content";
     final String filename = "devfile.yaml";
-    when(urlFetcher.fetch(anyString(), anyString())).thenReturn(rawContent);
+    when(bitbucketApiClient.getFileContent(
+            eq("test"), eq("repo"), eq("HEAD"), eq("devfile.yaml"), eq("my-token")))
+        .thenReturn(rawContent);
     var personalAccessToken = new PersonalAccessToken("foo", "che", "my-token");
     when(personalAccessTokenManager.getAndStore(anyString())).thenReturn(personalAccessToken);
 
@@ -76,4 +83,17 @@ public class BitbucketScmFileResolverTest {
 
     assertEquals(content, rawContent);
   }
+
+  @Test
+  public void shouldFetchContentWithoutAuthentication() throws Exception {
+    // given
+    when(personalAccessTokenManager.getAndStore(anyString()))
+        .thenThrow(new ScmUnauthorizedException("message", "bitbucket", "v1", "url"));
+
+    // when
+    bitbucketScmFileResolver.fileContent("https://bitbucket.org/username/repo.git", "devfile.yaml");
+
+    // then
+    verify(urlFetcher).fetch(anyString());
+  }
 }
