@@ -15,11 +15,13 @@ import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.*;
 
 import org.eclipse.che.api.factory.server.scm.PersonalAccessToken;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
+import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
 import org.eclipse.che.api.factory.server.urlfactory.DevfileFilenamesProvider;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 import org.mockito.Mock;
@@ -97,4 +99,17 @@ public class GithubScmFileResolverTest {
 
     assertEquals(content, rawContent);
   }
+
+  @Test
+  public void shouldReturnContentWithoutAuthentication() throws Exception {
+    // given
+    when(personalAccessTokenManager.getAndStore(anyString()))
+        .thenThrow(new ScmUnauthorizedException("message", "github", "v1", "url"));
+
+    // when
+    githubScmFileResolver.fileContent("https://github.com/username/repo.git", "devfile.yaml");
+
+    // then
+    verify(urlFetcher).fetch(anyString());
+  }
 }
