@@ -13,7 +13,6 @@ package org.eclipse.che.api.factory.server.gitlab;
 
 import java.io.IOException;
 import org.eclipse.che.api.factory.server.scm.AuthorizingFileContentProvider;
-import org.eclipse.che.api.factory.server.scm.GitCredentialManager;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 
@@ -23,9 +22,8 @@ class GitlabAuthorizingFileContentProvider extends AuthorizingFileContentProvide
   GitlabAuthorizingFileContentProvider(
       GitlabUrl gitlabUrl,
       URLFetcher urlFetcher,
-      GitCredentialManager gitCredentialManager,
       PersonalAccessTokenManager personalAccessTokenManager) {
-    super(gitlabUrl, urlFetcher, personalAccessTokenManager, gitCredentialManager);
+    super(gitlabUrl, urlFetcher, personalAccessTokenManager);
   }
 
   @Override
