@@ -14,6 +14,7 @@ package org.eclipse.che.api.factory.server.gitlab;
 import static org.eclipse.che.api.factory.shared.Constants.CURRENT_VERSION;
 import static org.eclipse.che.api.factory.shared.Constants.URL_PARAMETER_NAME;
 import static org.eclipse.che.dto.server.DtoFactory.newDto;
+import static org.eclipse.che.security.oauth1.OAuthAuthenticationService.ERROR_QUERY_NAME;
 
 import jakarta.validation.constraints.NotNull;
 import java.util.Map;
@@ -80,7 +81,9 @@ public class GitlabFactoryParametersResolver extends DefaultFactoryParameterReso
       throws ApiException {
     // no need to check null value of url parameter as accept() method has performed the check
     final GitlabUrl gitlabUrl = gitlabURLParser.parse(factoryParameters.get(URL_PARAMETER_NAME));
-
+    boolean skipAuthentication =
+        factoryParameters.get(ERROR_QUERY_NAME) != null
+            && factoryParameters.get(ERROR_QUERY_NAME).equals("access_denied");
     // create factory from the following location if location exists, else create default factory
     return urlFactoryBuilder
         .createFactoryFromDevfile(
@@ -88,7 +91,7 @@ public class GitlabFactoryParametersResolver extends DefaultFactoryParameterReso
             new GitlabAuthorizingFileContentProvider(
                 gitlabUrl, urlFetcher, personalAccessTokenManager),
             extractOverrideParams(factoryParameters),
-            false)
+            skipAuthentication)
         .orElseGet(() -> newDto(FactoryDto.class).withV(CURRENT_VERSION).withSource("repo"))
         .acceptVisitor(new GitlabFactoryVisitor(gitlabUrl));
   }
